@@ -10,7 +10,7 @@ def log(method):
                 print(f'INIT: {args[0]}')
             elif method.__name__ == '_get':
                 print(f'GET SERVICE {args[0]}')
-            elif method.__name__ == '_flush_self_cache':
+            elif method.__name__ == 'flush_cache':
                 print(f'FLUSH CACHE {args[0]}')
         result = method(*args, **kwargs)
         return result
